# `gppt`: get-pixivpy-token

- Get your Pixiv token (for running in pixivpy)
- Refine [pixiv_auth.py](https://gist.github.com/ZipFile/c9ebedb224406f4f11845ab700124362)

## Install

```bash
❭ pip install gppt
```

## Run

- Note: _In advance, please setup google-chrome-stable + selenium + webdriver_
- On Ubuntu, my setup script is available

```bash
❭ ./setup.sh
```

- Then

```bash
❭ gppt login
access_token: ***
refresh_token: ***
expires_in: 3600
```
